webutil [![Circle CI](https://circleci.com/gh/snarfed/oauth-dropins.svg?style=svg)](https://circleci.com/gh/snarfed/oauth-dropins) [![Coverage Status](https://coveralls.io/repos/github/snarfed/oauth-dropins/badge.svg?branch=master)](https://coveralls.io/github/snarfed/oauth-dropins?branch=master)
===

Common utilities and handler code for Python webapps. The [`util`](https://oauth-dropins.readthedocs.io/en/stable/source/oauth_dropins.webutil.html#module-oauth_dropins.webutil.util) module is general purpose; the rest of the modules are mostly specific to [Google App Engine](https://cloud.google.com/appengine/).

webutil is not developed, maintained, or distributed as a standalone package. Instead, it's distributed as part of the [oauth-dropins](https://oauth-dropins.readthedocs.io/) library.

* Install with `pip install oauth-dropins`.
* Supports Python 2.7+ and 3.3+.
* [Reference documentation.](https://oauth-dropins.readthedocs.io/en/stable/source/oauth_dropins.webutil.html)

webutil is public domain. You may also use it under the [CC0 public domain dedication](https://creativecommons.org/share-your-work/public-domain/cc0/).
